from agenda import Agenda
import sys
class Menu:
    def __init__(self):
        self.agenda = Agenda()
        self.opciones= {
            "1": self.nuevo_contacto,
            "2": self.modificar_ciudad,
            "3": self.modificar_direccion,
            "4": self.modificar_etiquetas,
            "5": self.modificar_fecha_nacimiento,
            "6": self.buscar,
            "7": self.alerta_cumples,
            "8": self.mostrar_contactos,
            "9": self.salir
        }

    def mostrar_menu(self):
        print("""
Menú de la agenda:
1. Ingresar nuevo contacto
2. Agregar o Modificar ciudad del contacto
3. Agregar o Modificar direccion del contacto
4. Agregar o Modificar etiqueta del contacto
5. Agregar o Modificar fecha de nacimiento del contacto
6. Buscar nombre, etiqueta y/o ciudad
7. Alerta sobre los cumpleaños proximos
8. Muestra todos los contactos
9. Salir
""")

    def ejecutar(self):
        '''Mostrar el menu y responder a las opciones.'''
        while True:
            self.mostrar_menu()
            opcion = input("Ingresar una opción: ")
            accion = self.opciones.get(opcion)
            if accion:
                accion()
            else:
                print("{0} no es una opción válida".format(opcion))

    def nuevo_contacto(self):
        """Solicita los datos del contacto nuevo y lo agrega a la agenda"""
        contacto = input("Ingrese el nombre: ")
        celular = input ("Ingrese el celular: ")
        direccion = input("Ingrese la direccion (opcional): ")
        ciudad = input("Ingrese la ciudad (opcional): ")
        etiquetas = input("Ingrese etiqueta (opcional): ")
                
        self.agenda.nuevo_contacto(contacto,celular,direccion,ciudad,etiquetas)
        

    def modificar_ciudad(self):
        """Solicita el id del contacto y el nombre de la ciudad y modifica
        los datos del contacto"""
        id_contacto = int(input("Ingrese el id del contacto: "))
        ciudad = input("Ingrese la nueva ciudad: ")
        self.agenda.modificar_ciudad(id_contacto, ciudad)

    def modificar_direccion(self):
        """Solicita el id del contacto y la dirección y modifica
        los datos del contacto"""
        id_contacto = int(input("Ingrese el id del contacto: "))
        direccion = input("Ingrese la nueva direccion: ")
        self.agenda.modificar_direccion(id_contacto, direccion)
    
    def modificar_etiquetas(self):
        """Solicita el id del contacto y las nuevas etiquetas y modifica
        los datos del contacto"""
        id_contacto = int(input("Ingrese el id del contacto: "))
        etiquetas = input("Ingrese la nueva etiqueta: ")
        self.agenda.modificar_etiquetas(id_contacto, etiquetas)

    def modificar_fecha_nacimiento(self):
        """Solicita el id del contacto y la nueva fecha de nacimiento y
        modifica los datos del contacto"""
        id_contacto = int(input("Ingrese el id del contacto: "))
        anio = int(input("Ingrese el año de nacimiento (4 dígitos): "))
        mes = int(input("Ingrese el mes de nacimiento (en número, 1 a 12): "))
        dia = int(input("Ingrese el dia de nacimiento: "))
        self.agenda.modificar_fecha_nacimiento(id_contacto, anio, mes, dia)

    def buscar(self): 
        """Solicita el filtro de búsqueda y muestra los usuarios que coinciden
        con el filtro ingresado"""
        filtro = input("Ingrese la palabra a buscar: ")
        b = self.agenda.buscar(filtro)
        if b:
            self.mostrar_contactos(b)
        else:
            print("La busqueda no genero resultados.")

    def alerta_cumples(self):
        """Solicita un número n y muestra los usuarios que cumplen años los
        próximos "n" días"""
        n = int(input("Ingrese el rango en dias: "))
        lista_cumples = self.agenda.alerta_cumples(n)
        self.mostrar_contactos(lista_cumples)


    def mostrar_contactos(self, lista = None):
        """Sin parámetros, muestra todos los usuarios.
        Si recibe una lista de usuarios, muestra los usuarios de la lista"""
        if lista == None:
            lista = self.agenda.contactos
        for un_contacto in lista:
            print(un_contacto.mostrar())

    def salir(self):
        """Sale del sistema"""
        print("Gracias por utilizar el sistema.")
        sys.exit(0)

if __name__ == "__main__":
    Menu().ejecutar()
